@@ -2,10 +2,9 @@
 
 This module is an argument serialization and deserialization library that:
 
-    - generates argparse.ArgumentParser based a `NamedTuple` class argument
-    - handles two-way conversions: a typed argument object (A `NamedTuple`) <-> a command-line argv
-    - enables IDE type hints and code auto-completion by using `NamedTuple`
-    - promotes type-safety of command-line arguments
+    - handles two-way conversions: a typed immutable argument object (A `NamedTuple` or `dataclass` instance) <==> a command-line argv
+    - enables IDE type hints and code auto-completion by using `NamedTuple` or `dataclass`
+    - promotes type-safety of cli-ready arguments
 
 
 The following is a simple usage example::
@@ -13,11 +12,11 @@ The following is a simple usage example::
     # Define the argument class:
     @arg_suite
     class MyArg(NamedTuple):
-        '''MyArg docstring goes to description
-        Each named (without "_" prefix) and fully typed attribute will be turned into an ArgumentParser.add_argument
-        '''
+        '''MyArg is smart and the docstring goes to description'''
 
         nn: List[int]  # Comments go to ArgumentParser argument help
+        # Each named (without "_" prefix) and fully typed attribute will be turned into an ArgumentParser.add_argument
+        # DISCOURAGED: This only overrides one-way conversion (deserialization of cli) behavior and introduces inconsistencies.
         _nn = {'choices': (200, 300)}  # (Advanced feature) Optional user supplement/override for `ArgumentParser.add_argument("--nn", **(kwargs|_nn))`
 
         a_tuple: Tuple[str, int]  # Arguments without defaults are treated as "required = True"
@@ -31,9 +30,9 @@ The following is a simple usage example::
 
     # Create the corresponding argument class instance from the command line argument list:
     # by using
-    parsed_arg: ArgClass = ArgClass.__from_argv__(sys.argv[1:])  # with factory method, need the manual type hint `:ArgClass` to help IDE
-    # or the monkey-patched constructor of the annotated NameTuple argument class
-    parsed_arg = ArgClass(sys.argv[1:])  # with monkey-patched constructor with one positional argument, no manual hint needed
+    arg: ArgClass = ArgClass.__from_argv__(sys.argv[1:])  # with factory method, need the manual type hint `:ArgClass` to help IDE
+    # or the monkey-patched constructor of the annotated argument class
+    arg = ArgClass(sys.argv[1:])  # with monkey-patched constructor with one positional argument, no manual hint needed
 
     # Create a NamedTuple argument instance and generate its command line counterpart:
     # the monkey-patched constructor only take named arguments for directly creating the NamedTuple
@@ -44,12 +43,9 @@ The following is a simple usage example::
 
 The module contains the following public classes:
 
-- `arg_suite` -- The main entry point for command-line argument suite. As the
-    example above shows, this decorator will attach an ArgSuite instance to
-    the argument `NamedTuple` "subclass".
-
-- `ArgSuite` -- The main class that generates the corresponding `ArgumentParser`
-    and handles the two-way conversions.
+- `arg_suite` -- The main entry point for smart arguments suite. As the
+    example above shows, this decorator will attach an `ArgSuite` instance to
+    the argument `NamedTuple` or `dataclass`.
 
 - `PrimitiveHandlerAddon` -- The base class to handle primitive types, and users can
     implement their owns to change the behavior.
@@ -65,7 +61,8 @@ __all__ = (
     'LateInit',
     'SmartArgError',
     'TypeHandler',
-    'PrimitiveHandlerAddon')
+    'PrimitiveHandlerAddon',
+)
 
 import logging
 import os
@@ -77,6 +74,7 @@ from argparse import Action, ArgumentParser
 from types import SimpleNamespace as KwargsType
 from typing import Any, Collection, Dict, Generic, Iterable, List, NamedTuple, Optional, Sequence, Set, Tuple, Type, TypeVar, Union
 
+__version__ = '0.2.*'
 ArgType = TypeVar('ArgType', bound=NamedTuple)  # NamedTuple is not a real class bound, but setting `bound` to NamedTuple makes mypy happier
 NoneType = None.__class__
 FieldMeta = NamedTuple('FieldMeta', (('comment', str), ('default', Any), ('type', Type)))
@@ -92,17 +90,14 @@ if SMART_ARG_LOG_LEVEL in os.environ:
     logger.setLevel(log_level)
     logger.info(f"Detected environment var `{SMART_ARG_LOG_LEVEL}, set log level to '{log_level}' and log to stream.")
 
-if sys.version_info >= (3, 8):
-    logger.info(f"Python {sys.version_info} >= 3.8. from typing import get_origin, get_args ")
-    from typing import get_args, get_origin
-elif sys.version_info >= (3, 7):
-    logger.info(f"Python {sys.version_info} == 3.7.x. Defining get_origin, get_args ")
+if sys.version_info >= (3, 7):
+    # Python == 3.7.x. Defining the back-ported get_origin, get_args
     # 3.7 `List.__origin__ == list`
-    get_origin, get_args = lambda tp: getattr(tp, '__origin__', None), lambda tp: getattr(tp, '__args__', ())  # noqa: E731
+    get_origin, get_args = lambda tp: getattr(tp, '__origin__', None), lambda tp: getattr(tp, '__args__', ())
 elif sys.version_info >= (3, 6):
-    logger.info(f"Python {sys.version_info} == 3.6.x. Defining get_origin, get_args ")
+    # Python == 3.6.x. Defining the back-ported get_origin, get_args
     # 3.6 `List.__origin__ == List`, `Optional` does not have `__dict__`
-    get_origin, get_args = lambda tp: getattr(tp, '__extra__', ()) or getattr(tp, '__origin__', None), lambda tp: getattr(tp, '__args__', ())  # noqa: E731
+    get_origin, get_args = lambda tp: getattr(tp, '__extra__', ()) or getattr(tp, '__origin__', None), lambda tp: getattr(tp, '__args__', ())
 else:
     try:
         warnings.warn(f"Unsupported and untested python version {sys.version_info} < 3.6. "
@@ -116,7 +111,7 @@ else:
 
 _black_hole = lambda *args, **kwargs: None
 try:
-    from dataclasses import MISSING, asdict, is_dataclass
+    from dataclasses import FrozenInstanceError, MISSING, asdict, is_dataclass
 except ImportError:
     logger.warning("Importing dataclasses failed. You might need to 'pip install dataclasses' on python 3.6.")
     class MISSING: pass  # type: ignore # noqa: E701
@@ -127,7 +122,8 @@ class LateInit:
     """special singleton/class to mark late initialized fields"""
 
 
-class SmartArgError(Exception): pass  # noqa: E701 # TODO Extend to better represent different types of errors.
+class SmartArgError(Exception):  # TODO Extend to better represent different types of errors.
+    """Base exception for smart-arg."""
 
 
 class PrimitiveHandlerAddon:
@@ -141,8 +137,18 @@ class PrimitiveHandlerAddon:
             kwargs.choices = [True, False]
 
     @staticmethod
-    def build_type(arg_type: Type):
+    def build_type(arg_type: Type) -> Any:
         return (lambda s: True if s == 'True' else False if s == 'False' else s) if arg_type is bool else arg_type
+
+    @staticmethod
+    def str(arg: Any) -> str:
+        """Define to serialize the `arg` to a string.
+
+        :param arg: The argument
+        :type arg: Any type that is supported by this class
+        :return: The string serialization of `arg`
+        """
+        return str(arg)
     handled_types: Collection[Type] = PRIMITIVES
 
 
@@ -162,18 +168,16 @@ class TypeHandler:
         help_builder = ['(', self.type_to_str(arg_type)]
         # Get default if specified and set required if no default
         if field_meta.default is MISSING:
-            # TODO handle positional if we decided to support it later
             kwargs.required = True
             help_builder.append(', required')
         else:
-            # Only add default to the help message for informational purpose. The default is set when creating the NamedTuple.
-            # kwargs.default = field_meta.default  # left for reference purpose
+            # Only add default to the help message for informational purpose. The default is set when creating the argument class instance.
             help_builder.append(', default: ')
             help_builder.append(str(field_meta.default))
 
         help_builder.append(')')
-        # Add from source code comment
         help_builder.append(' ')
+        # Add from source code comment
         help_builder.append(field_meta.comment)
         kwargs.help = ''.join(help_builder)
 
@@ -206,9 +210,9 @@ class TypeHandler:
         :return: iterable command line str"""
         yield action.option_strings[0]
         if not isinstance(arg, str) and isinstance(arg, Iterable):
-            yield from (str(a) for a in arg)
+            yield from (self.primitive_addons[type(a)].str(a) for a in arg)
         else:
-            yield str(arg)
+            yield self.primitive_addons[type(arg)].str(arg)
 
     @staticmethod
     def type_to_str(t: Union[type, Type]) -> str:
@@ -258,11 +262,11 @@ class CollectionHandler(TypeHandler):
         """Build other information for the keyword argument KwargsType object
 
         :param kwargs: the keyword argument KwargsType object
-        :param arg_type: the type of the argument extracted from NamedTuple (List/Set type)"""
-        self.arg_types: Tuple[Type, ...] = get_args(arg_type)  # type: ignore
+        :param arg_type: the type of the argument extracted from the argument class (List/Set type)"""
+        self.arg_types: Tuple[Type, ...] = get_args(arg_type)
         self.unboxed_type = self.arg_types[0]
         kwargs.metavar = self.type_to_str(self.unboxed_type)
-        kwargs.nargs = '*'  # Consider using comment to specify the number of size of the collection
+        kwargs.nargs = '*'
         kwargs.type = self.unboxed_type
     handled_types = {Box[p] for Box in [List, Set] for p in PRIMITIVES}  # type: ignore
 
@@ -272,13 +276,13 @@ class DictHandler(CollectionHandler):
         """Build other information for the keyword argument KwargsType object
 
         :param kwargs: the keyword argument KwargsType object
-        :param arg_type: the type of the argument extracted from NamedTuple (Dict type)"""
+        :param arg_type: the type of the argument extracted from the argument class (Dict type)"""
         super()._build_other(kwargs, arg_type)
         arg_types = self.arg_types
 
         def type_fun(s: str, types=arg_types):
             k, v = s.split(":")
-            type_builder = lambda t: self.primitive_addons[t].build_type(t)  # noqa: E731
+            type_builder = lambda t: self.primitive_addons[t].build_type(t)
             return type_builder(types[0])(k), type_builder(types[1])(v)
 
         kwargs.type = type_fun
@@ -291,21 +295,22 @@ class DictHandler(CollectionHandler):
 
 
 class _namedtuple:  # TODO expand lambdas to static methods or use a better holder representation
-    """Helper function holder for NamedTuple support"""
+    """A NamedTuple proxy, helper function holder for NamedTuple support"""
     @staticmethod
     def new_instance(arg_class, kwargs):
-        """Replacement for NamedTuple.__new__: call original __new__ -> __post_init__ -> post_validation"""
+        """:return A new instance of `arg_class`: call original __new__ -> __post_init__ -> post_validation"""
         new_instance = arg_class.__original_new__(arg_class, **kwargs)
-        post_init = getattr(arg_class, '__post_init__', lambda me: me)
-        fake_namedtuple = KwargsType(**new_instance._asdict())
-        post_init(fake_namedtuple)  # make the faked NamedTuple mutable only in post_init
-        new_instance = arg_class.__original_new__(arg_class, **vars(fake_namedtuple))
+        post_init = getattr(arg_class, '__post_init__', None)
+        if post_init:
+            fake_namedtuple = KwargsType(**new_instance._asdict())
+            post_init(fake_namedtuple)  # make the faked NamedTuple mutable in post_init only while initialization
+            new_instance = arg_class.__original_new__(arg_class, **vars(fake_namedtuple))
         arg_class.__arg_suite__.post_validation(new_instance)
         return new_instance
 
     @staticmethod
-    def is_supported(t):
-        """:return this class if supported or None"""
+    def proxy(t: Type):
+        """:return This proxy class if `t` is a `NamedTuple` or `None`"""
         b, f, f_t = getattr(t, '__bases__', []), getattr(t, '_fields', []), getattr(t, '__annotations__', {})
         return _namedtuple if (len(b) == 1 and b[0] == tuple and isinstance(f, tuple) and isinstance(f_t, dict)
                                and all(type(n) == str for n in f) and all(type(n) == str for n, _ in f_t.items())) else None
@@ -317,32 +322,31 @@ class _namedtuple:  # TODO expand lambdas to static methods or use a better hold
 class _dataclasses:
     @staticmethod
     def patch(cls):
-        def throw_if_frozen(self, fun, *args, **kwargs):
+        """Patch the argument dataclass so that `post_validation` is called and it's immutable if not `frozen` after initialization"""
+        def throw_if_frozen(self, fun, name, *args, **kwargs):
             if getattr(self, '__frozen__', False):
-                raise SmartArgError(f"{self.__class__} instance is frozen.")
+                raise FrozenInstanceError(f"cannot assign to/delete field {name!r}")
             else:
-                object.__setattr__(self, *args, **kwargs)
+                getattr(object, fun)(self, name, *args, **kwargs)
 
-        def smart_arg_post_init(self, *args, **kwargs):
-            original_post_init = getattr(self, '__original_post_init__', _black_hole)
-            original_post_init(*args, **kwargs)
+        def init(self, *args, **kwargs):
+            if args and hasattr(self, '__frozen__'):
+                logger.debug(f"Assuming {self} is from patch new with __from_argv__, already initialized, skipping init.")
+                return
+            self.__original_init__(*args, **kwargs)
             object.__setattr__(self, '__frozen__', True)
             self.__class__.__arg_suite__.post_validation(self)
-        o_p_i = getattr(cls, '__post_init__', smart_arg_post_init)
-        if o_p_i.__name__ != smart_arg_post_init.__name__:
-            cls.__original_post_init__ = o_p_i
-        cls.__post_init__ = smart_arg_post_init
-        if not cls.__dataclass_params__.frozen:
-            cls.__setattr__ = lambda self, *args, **kwargs: throw_if_frozen(self, '__setattr__', *args, **kwargs)
-            cls.__delattr__ = lambda self, *args, **kwargs: throw_if_frozen(self, '__delattr__', *args, **kwargs)
-    is_supported = lambda t: _dataclasses if is_dataclass(t) else None
+        cls.__init__, cls.__original_init__ = init, cls.__init__
+        cls.__setattr__ = lambda self, name, value: throw_if_frozen(self, '__setattr__', name, value)
+        cls.__delattr__ = lambda self, name, : throw_if_frozen(self, '__delattr__', name)
+    proxy = lambda t: _dataclasses if is_dataclass(t) else None
     asdict = lambda args: asdict(args)
     field_default = lambda arg_class, raw_arg_name: arg_class.__dataclass_fields__[raw_arg_name].default
     new_instance = lambda arg_class, _: arg_class.__original_new__(arg_class)
 
 
 def _get_type_proxy(arg_class):
-    return _namedtuple.is_supported(arg_class) or _dataclasses.is_supported(arg_class)
+    return _namedtuple.proxy(arg_class) or _dataclasses.proxy(arg_class)
 
 
 _mro_all = lambda arg_class, get_dict: {k: v for b in (*arg_class.__mro__[-1:0:-1], arg_class) if b.__module__ != 'builtins' for k, v in get_dict(b).items()}
@@ -351,12 +355,13 @@ _annotations = lambda arg_class: _mro_all(arg_class, lambda b: getattr(b, '__ann
 
 
 class ArgSuite(Generic[ArgType]):
+    """Generates the corresponding `ArgumentParser` and handles the two-way conversions."""
     @staticmethod
     def new_arg(arg_class, *args, **kwargs):
-        """Monkey-Patched NamedTuple constructor __new__.
+        """Monkey-Patched argument class __new__.
         If any positional arguments exist, it would assume that the user is trying to parse a sequence of strings.
-        It would also assume there is only one positional argument, and raise an SmartArgError otherwise.
-        If no positional arguments exist, it would call the original NamedTuple constructor with all keyword arguments.
+        It would also assume there is only one positional argument, and raise an `SmartArgError` otherwise.
+        If no positional arguments exist, it would call the argument class instance creator with all keyword arguments.
 
         :param arg_class: Decorated class
         :param args: Optional positional argument, to be parsed to the arg_class type.
@@ -365,16 +370,17 @@ class ArgSuite(Generic[ArgType]):
                `args[1]`: default to `None`, indicating using the default separator for the argument class
 
         :type `(Optional[Sequence[str]], Optional[str])`
-        :param kwargs: Optional keyword arguments, to be passed to the original NamedTuple constructor."""
-        logger.info(f"Patched new for {arg_class} is called with {args} and {kwargs}.")
+        :param kwargs: Optional keyword arguments, to be passed to the argument class specific instance creator."""
+        logger.debug(f"Patched new for {arg_class} is called with {args} and {kwargs}.")
         if args:
+            warnings.warn(f"Calling the patched constructor of {arg_class} with argv is deprecated, please use {arg_class}.__from_argv__ instead.")
             # TODO Exception handling with helpful error message
             if (kwargs or len(args) > 2 or len(args) == 2 and args[1].__class__ not in (NoneType, str)
                     or not (args[0] is None or isinstance(args[0], Sequence) and all(a.__class__ is str for a in args[0]))):
                 raise SmartArgError(f"Calling '{arg_class}(positional {args}, keyword {kwargs})' is not allowed:\n"
                                     f"Only accept positional arguments to parse to the '{arg_class}'\n"
                                     f"keyword arguments can only be used to create an instance directly.")
-            return arg_class.__arg_suite__.parse_to_arg(*args)
+            return arg_class.__from_argv__(args[0])
         else:
             return _get_type_proxy(arg_class).new_instance(arg_class, kwargs)
 
@@ -398,7 +404,7 @@ class ArgSuite(Generic[ArgType]):
 
     def __call__(self, arg_class):
         type_proxy = _get_type_proxy(arg_class)
-        assert type_proxy, f"Unsupported argument class {arg_class}"
+        assert type_proxy, f"Unsupported argument class {arg_class}."
 
         self.handler_actions: Dict[str, Union[Tuple[TypeHandler, Action], Tuple[None, Any]]] = {}
 
@@ -407,17 +413,17 @@ class ArgSuite(Generic[ArgType]):
         if not hasattr(arg_class, '__original_new__'):
             arg_class.__original_new__ = arg_class.__new__
         arg_class.__new__ = ArgSuite.new_arg
-        arg_class.__to_argv__ = lambda s, separator='': self.to_cmd_argv(s, separator)  # instance level method
+        arg_class.__to_argv__ = lambda arg_self, separator='': self.to_cmd_argv(arg_self, separator)  # arg_class instance level method
         arg_class.__from_argv__ = self.parse_to_arg
         arg_class.__arg_suite__ = self
         self._arg_class = arg_class
-        self._parser = ArgumentParser(description=self._arg_class.__doc__, argument_default=MISSING, fromfile_prefix_chars='@')  # type: ignore
+        self._parser = ArgumentParser(description=self._arg_class.__doc__, argument_default=MISSING, fromfile_prefix_chars='@')
         self._parser.convert_arg_line_to_args = lambda arg_line: arg_line.split()
         self._gen_arguments_from_class(self._arg_class, '', True, [], type_proxy)
         return arg_class
 
-    def _validate_fields(self, arg_class, type_proxy) -> None:
-        """Validate fields in the decorated class.
+    def _validate_fields(self, arg_class: Type) -> None:
+        """Validate fields in `arg_class`.
 
         :raise: SmartArgError if the decorated argument class has non-typed field with defaults and such field
                 does not startswith "_" to overwrite the existing argument field property."""
@@ -425,9 +431,9 @@ class ArgSuite(Generic[ArgType]):
         invalid_fields = list(filter(lambda s: s.endswith('_'), arg_fields))
         if invalid_fields:
             raise SmartArgError(f"'{arg_class}': found invalid (ending with '_') fields : {invalid_fields}.")
-        # skip callable methods and typed fields
         prefix = f'_{arg_class.__name__}__'
         l_prefix = len(prefix)
+        # skip callable methods and typed fields
         for f in [f for f in (vars(arg_class).keys()) if not callable(getattr(arg_class, f)) and f not in arg_fields]:
             if f.startswith(prefix):
                 if f[l_prefix:] not in arg_fields:
@@ -444,7 +450,7 @@ class ArgSuite(Generic[ArgType]):
         elif not (suite and suite._arg_class is arg_class) and (hasattr(arg_class, '__post_init__')):
             raise SmartArgError(f"Nested argument class '{arg_class}' with '__post_init__' expected to be decorated.")
         else:
-            self._validate_fields(arg_class, type_proxy)
+            self._validate_fields(arg_class)
             comments = _mro_all(arg_class, self.get_comments)
             for raw_arg_name, arg_type in _annotations(arg_class).items():
                 arg_name = f'{prefix}{raw_arg_name}'
@@ -475,12 +481,12 @@ class ArgSuite(Generic[ArgType]):
                     else:
                         # fallback to special handling for the types which can not be fully enumerated, e.g. tuple
                         type_origin = get_origin(arg_type)
-                        type_args: tuple = get_args(arg_type)  # type: ignore
+                        type_args: tuple = get_args(arg_type)
                         if type_origin == Union and len(type_args) == 2 and type_args[1] == NoneType:
                             arg_type = type_args[0]
                             if default not in (None, LateInit):
                                 raise SmartArgError(f"Optional field: {arg_name} must default to None or 'LateInit', but got {default}")
-                        handler = self.handlers.get(arg_type) or self.fallback_handlers.get(get_origin(arg_type))  # type: ignore
+                        handler = self.handlers.get(arg_type) or self.fallback_handlers.get(get_origin(arg_type))
                         if not handler:
                             raise SmartArgError(f"Unsupported type: Optional/{arg_type} with origin {type_origin} for '{arg_name}'")
                         field_meta = FieldMeta(comment=comments.get(raw_arg_name, ''), default=default, type=arg_type)
@@ -538,19 +544,20 @@ class ArgSuite(Generic[ArgType]):
                 if arg_type_flag:
                     value = arg_dict.get(arg_name, MISSING)
                     type_origin = get_origin(arg_type)
-                    type_args: tuple = get_args(arg_type)  # type: ignore
+                    type_args: tuple = get_args(arg_type)
                     type_to_new = get_origin(type_args[0]) if type_origin == Union and len(type_args) == 2 and type_args[1] == NoneType else type_origin
                     # argparse reading variable length arguments are all lists, need to apply the origin type for the conversion to correct type.
-                    value = type_to_new(value) if value is not None and isinstance(value, List) else value  # type: ignore
+                    value = type_to_new(value) if value is not None and isinstance(value, List) else value
                 else:
                     is_nested = any((name for name in arg_dict.keys() if name.startswith(arg_name)))
-                    value = to_arg(arg_type, f'{arg_name}.') if is_nested else default  # type: ignore
+                    value = to_arg(arg_type, f'{arg_name}.') if is_nested else default
                 if value is not MISSING:
                     nest_arg[raw_arg_name] = value
             return arg_class(**nest_arg)
         return to_arg(self._arg_class, '')
 
     def post_validation(self, arg: ArgType) -> None:
+        """This is called after __post_init__ to validate the fields."""
         arg_class = arg.__class__
         for f, t in _annotations(arg_class).items():
             attr = getattr(arg, f)
@@ -625,13 +632,13 @@ class ArgSuite(Generic[ArgType]):
 
 
 def custom_arg_suite(type_handlers: List[Type[TypeHandler]] = None, primitive_handler_addons: List[Type[PrimitiveHandlerAddon]] = None):
-    """Generate a decorator on NamedTuple class to easily convert back and forth from commandline to NamedTuple class.
+    """Generate a decorator to easily convert back and forth from command-line to `NamedTuple` or `dataclass`.
 
     The decorator monkey patches the constructor, so that the IDE would infer the type of
-    parsed_arg for code auto completion and type check::
+    the deserialized `arg` for code auto completion and type check::
 
-        parsed_arg: ArgClass = ArgClass.from_argv(my_argv)  # Factory method, need the manual type hint `:ArgClass`
-        parsed_arg = ArgClass(my_argv)  # with monkey-patched constructor, no manual hint needed
+        arg: ArgClass = ArgClass.__from_argv__(my_argv)  # Factory method, need the manual type hint `:ArgClass`
+        arg = ArgClass(my_argv)  # with monkey-patched constructor, no manual hint needed
 
     For NamedTuple fields without types but with default values: only fields starts with "_" to overwrite the existed
     argument parameters are allowed; others will throw SmartArgError.
@@ -647,7 +654,7 @@ def custom_arg_suite(type_handlers: List[Type[TypeHandler]] = None, primitive_ha
 
     :param primitive_handler_addons: the primitive types handling in addition to the provided primitive types handling
     :param type_handlers: the non-primitive types handling in addition to the provided types handling.
-    :return: the argument class (NamedTuple) decorator"""
+    :return: the argument class decorator"""
     def decorator(cls):
         return ArgSuite(type_handlers, primitive_handler_addons)(cls)
     return decorator
